@@ -9,4 +9,4 @@ options(error=recover)
 sapply(files, testExport)
 
 ## test GRanges imports
-sapply(files[-8], import, asRangedData = FALSE)
+sapply(files[-8], import)
